/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db;

public class Table extends com.mysql.grt.db.DatabaseObject {

    protected Table() {
    }

    public Table(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new TableDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new TableDataGlobal((String) obj);
        }
    }

    public int getIsTemporary() {
        return ((TableData) data).getIsTemporary();
    }

    public int setIsTemporary(int isTemporary) {
        ((TableData) data).setIsTemporary(isTemporary);

        return getIsTemporary();
    }

    public int getIsSystem() {
        return ((TableData) data).getIsSystem();
    }

    public int setIsSystem(int isSystem) {
        ((TableData) data).setIsSystem(isSystem);

        return getIsSystem();
    }

    public String getTemporaryScope() {
        return ((TableData) data).getTemporaryScope();
    }

    public String setTemporaryScope(String temporaryScope) {
        ((TableData) data).setTemporaryScope(temporaryScope);

        return getTemporaryScope();
    }

    public com.mysql.grt.db.StructuredDatatype getTemplate() {
        return ((TableData) data).getTemplate();
    }

    public com.mysql.grt.db.StructuredDatatype setTemplate(com.mysql.grt.db.StructuredDatatype template) {
        ((TableData) data).setTemplate(template);

        return getTemplate();
    }

    public com.mysql.grt.db.ColumnList getColumns() {
        return ((TableData) data).getColumns();
    }

    public com.mysql.grt.db.ColumnList setColumns(com.mysql.grt.db.ColumnList columns) {
        ((TableData) data).setColumns(columns);

        return getColumns();
    }

    public com.mysql.grt.db.IndexList getIndices() {
        return ((TableData) data).getIndices();
    }

    public com.mysql.grt.db.IndexList setIndices(com.mysql.grt.db.IndexList indices) {
        ((TableData) data).setIndices(indices);

        return getIndices();
    }

    public com.mysql.grt.db.ForeignKeyList getForeignKeys() {
        return ((TableData) data).getForeignKeys();
    }

    public com.mysql.grt.db.ForeignKeyList setForeignKeys(com.mysql.grt.db.ForeignKeyList foreignKeys) {
        ((TableData) data).setForeignKeys(foreignKeys);

        return getForeignKeys();
    }

    public com.mysql.grt.db.TriggerList getTriggers() {
        return ((TableData) data).getTriggers();
    }

    public com.mysql.grt.db.TriggerList setTriggers(com.mysql.grt.db.TriggerList triggers) {
        ((TableData) data).setTriggers(triggers);

        return getTriggers();
    }

    public com.mysql.grt.db.Index getPrimaryKey() {
        return ((TableData) data).getPrimaryKey();
    }

    public com.mysql.grt.db.Index setPrimaryKey(com.mysql.grt.db.Index primaryKey) {
        ((TableData) data).setPrimaryKey(primaryKey);

        return getPrimaryKey();
    }

    public String getPrimaryKeyById() {
        return ((TableData) data).getPrimaryKeyById();
    }

    public void setPrimaryKeyById(String primaryKey) {
        ((TableData) data).setPrimaryKeyById(primaryKey);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"isTemporary\">"
                    + Integer.toString(getIsTemporary()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"isSystem\">"
                    + Integer.toString(getIsSystem()) + "</value>\n");

            if (getTemporaryScope() != null) {
                xml.append("<value type=\"string\" key=\"temporaryScope\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getTemporaryScope()) + "</value>\n");
            }

            if (getColumns() != null) {
                getColumns().getGrtXml(xml, " key=\"columns\"");
            }

            if (getIndices() != null) {
                getIndices().getGrtXml(xml, " key=\"indices\"");
            }

            if (getForeignKeys() != null) {
                getForeignKeys().getGrtXml(xml, " key=\"foreignKeys\"");
            }

            if (getTriggers() != null) {
                getTriggers().getGrtXml(xml, " key=\"triggers\"");
            }

            if (getTemplate() != null) {
                getTemplate().getGrtXml(xml, " key=\"template\"");
            }

            if (getPrimaryKey() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"primaryKey\">"
                        + getPrimaryKeyById() + "</value>\n");
            }

        return xml;
    }
}
