/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db;

public class Trigger extends com.mysql.grt.base.NamedGrtObject {

    protected Trigger() {
    }

    public Trigger(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new TriggerDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new TriggerDataGlobal((String) obj);
        }
    }

    public int getOrder() {
        return ((TriggerData) data).getOrder();
    }

    public int setOrder(int order) {
        ((TriggerData) data).setOrder(order);

        return getOrder();
    }

    public int getEnabled() {
        return ((TriggerData) data).getEnabled();
    }

    public int setEnabled(int enabled) {
        ((TriggerData) data).setEnabled(enabled);

        return getEnabled();
    }

    public String getEvent() {
        return ((TriggerData) data).getEvent();
    }

    public String setEvent(String event) {
        ((TriggerData) data).setEvent(event);

        return getEvent();
    }

    public String getCondition() {
        return ((TriggerData) data).getCondition();
    }

    public String setCondition(String condition) {
        ((TriggerData) data).setCondition(condition);

        return getCondition();
    }

    public String getStatement() {
        return ((TriggerData) data).getStatement();
    }

    public String setStatement(String statement) {
        ((TriggerData) data).setStatement(statement);

        return getStatement();
    }

    public String getOrientation() {
        return ((TriggerData) data).getOrientation();
    }

    public String setOrientation(String orientation) {
        ((TriggerData) data).setOrientation(orientation);

        return getOrientation();
    }

    public String getTiming() {
        return ((TriggerData) data).getTiming();
    }

    public String setTiming(String timing) {
        ((TriggerData) data).setTiming(timing);

        return getTiming();
    }

    public String getReferenceNewTable() {
        return ((TriggerData) data).getReferenceNewTable();
    }

    public String setReferenceNewTable(String referenceNewTable) {
        ((TriggerData) data).setReferenceNewTable(referenceNewTable);

        return getReferenceNewTable();
    }

    public String getReferenceOldTable() {
        return ((TriggerData) data).getReferenceOldTable();
    }

    public String setReferenceOldTable(String referenceOldTable) {
        ((TriggerData) data).setReferenceOldTable(referenceOldTable);

        return getReferenceOldTable();
    }

    public String getReferenceNewRow() {
        return ((TriggerData) data).getReferenceNewRow();
    }

    public String setReferenceNewRow(String referenceNewRow) {
        ((TriggerData) data).setReferenceNewRow(referenceNewRow);

        return getReferenceNewRow();
    }

    public String getReferenceOldRow() {
        return ((TriggerData) data).getReferenceOldRow();
    }

    public String setReferenceOldRow(String referenceOldRow) {
        ((TriggerData) data).setReferenceOldRow(referenceOldRow);

        return getReferenceOldRow();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"order\">"
                    + Integer.toString(getOrder()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"enabled\">"
                    + Integer.toString(getEnabled()) + "</value>\n");

            if (getEvent() != null) {
                xml.append("<value type=\"string\" key=\"event\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getEvent()) + "</value>\n");
            }

            if (getCondition() != null) {
                xml.append("<value type=\"string\" key=\"condition\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getCondition()) + "</value>\n");
            }

            if (getStatement() != null) {
                xml.append("<value type=\"string\" key=\"statement\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getStatement()) + "</value>\n");
            }

            if (getOrientation() != null) {
                xml.append("<value type=\"string\" key=\"orientation\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getOrientation()) + "</value>\n");
            }

            if (getTiming() != null) {
                xml.append("<value type=\"string\" key=\"timing\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getTiming()) + "</value>\n");
            }

            if (getReferenceNewTable() != null) {
                xml.append("<value type=\"string\" key=\"referenceNewTable\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getReferenceNewTable()) + "</value>\n");
            }

            if (getReferenceOldTable() != null) {
                xml.append("<value type=\"string\" key=\"referenceOldTable\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getReferenceOldTable()) + "</value>\n");
            }

            if (getReferenceNewRow() != null) {
                xml.append("<value type=\"string\" key=\"referenceNewRow\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getReferenceNewRow()) + "</value>\n");
            }

            if (getReferenceOldRow() != null) {
                xml.append("<value type=\"string\" key=\"referenceOldRow\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getReferenceOldRow()) + "</value>\n");
            }

        return xml;
    }
}
