/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.model;

public class Element extends com.mysql.grt.GrtObject {

    protected Element() {
    }

    public Element(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new ElementDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new ElementDataGlobal((String) obj);
        }
    }

    public int getVisible() {
        return ((ElementData) data).getVisible();
    }

    public int setVisible(int visible) {
        ((ElementData) data).setVisible(visible);

        return getVisible();
    }

    public int getEnabled() {
        return ((ElementData) data).getEnabled();
    }

    public int setEnabled(int enabled) {
        ((ElementData) data).setEnabled(enabled);

        return getEnabled();
    }

    public int getLocked() {
        return ((ElementData) data).getLocked();
    }

    public int setLocked(int locked) {
        ((ElementData) data).setLocked(locked);

        return getLocked();
    }

    public int getExpanded() {
        return ((ElementData) data).getExpanded();
    }

    public int setExpanded(int expanded) {
        ((ElementData) data).setExpanded(expanded);

        return getExpanded();
    }

    public double getLeft() {
        return ((ElementData) data).getLeft();
    }

    public double setLeft(double left) {
        ((ElementData) data).setLeft(left);

        return getLeft();
    }

    public double getTop() {
        return ((ElementData) data).getTop();
    }

    public double setTop(double top) {
        ((ElementData) data).setTop(top);

        return getTop();
    }

    public double getWidth() {
        return ((ElementData) data).getWidth();
    }

    public double setWidth(double width) {
        ((ElementData) data).setWidth(width);

        return getWidth();
    }

    public double getHeight() {
        return ((ElementData) data).getHeight();
    }

    public double setHeight(double height) {
        ((ElementData) data).setHeight(height);

        return getHeight();
    }

    public String getLayoutClass() {
        return ((ElementData) data).getLayoutClass();
    }

    public String setLayoutClass(String layoutClass) {
        ((ElementData) data).setLayoutClass(layoutClass);

        return getLayoutClass();
    }

    public com.mysql.grt.model.Layer getLayer() {
        return ((ElementData) data).getLayer();
    }

    public com.mysql.grt.model.Layer setLayer(com.mysql.grt.model.Layer layer) {
        ((ElementData) data).setLayer(layer);

        return getLayer();
    }

    public String getLayerById() {
        return ((ElementData) data).getLayerById();
    }

    public void setLayerById(String layer) {
        ((ElementData) data).setLayerById(layer);
    }

    public com.mysql.grt.model.Group getGroup() {
        return ((ElementData) data).getGroup();
    }

    public com.mysql.grt.model.Group setGroup(com.mysql.grt.model.Group group) {
        ((ElementData) data).setGroup(group);

        return getGroup();
    }

    public String getGroupById() {
        return ((ElementData) data).getGroupById();
    }

    public void setGroupById(String group) {
        ((ElementData) data).setGroupById(group);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"visible\">"
                    + Integer.toString(getVisible()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"enabled\">"
                    + Integer.toString(getEnabled()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"locked\">"
                    + Integer.toString(getLocked()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"expanded\">"
                    + Integer.toString(getExpanded()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"left\">"
                    + Double.toString(getLeft()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"top\">"
                    + Double.toString(getTop()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"width\">"
                    + Double.toString(getWidth()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"height\">"
                    + Double.toString(getHeight()) + "</value>\n");

            if (getLayoutClass() != null) {
                xml.append("<value type=\"string\" key=\"layoutClass\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getLayoutClass()) + "</value>\n");
            }

            if (getLayer() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"layer\">"
                        + getLayerById() + "</value>\n");
            }

            if (getGroup() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"group\">"
                        + getGroupById() + "</value>\n");
            }

        return xml;
    }
}
